fnss.netconfig.nodeconfig.clear_applications — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.clear_applications

`clear_applications`(topology)

  Remove all applications from all nodes of the topology

  Parameters: | topology : Topology The topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »